@@ -99,7 +99,7 @@ class EngagementRateFB:
                     df_fan_count["created_at"]
                 ) - timedelta(hours=5)
                 df_fan_count["date"] = df_fan_count["created_at"].apply(
-                    lambda d: d.date
+                    lambda d: d.date()
                 )
                 df_fan_count = df_fan_count.drop(columns=["created_at"])
 
@@ -116,7 +116,7 @@ class EngagementRateFB:
                     df_posts_full["created_time"]
                 ) - timedelta(hours=5)
                 df_posts_full["date"] = df_posts_full["created_time"].apply(
-                    lambda d: d.date
+                    lambda d: d.date()
                 )
                 df_posts_full = pd.merge(
                     df_posts_full, df_fan_count, on=["page_id", "date"], how="left"
@@ -615,3 +615,74 @@ class EngagementRateFB:
                 ],
                 dtype=object,
             )
+
+    def normalize_eng_by_day(self, df_by_day, win=7):
+        """
+        This method computes normalize engagement rate by day
+        based on window average. It stores it on the column
+        'engagement_norm' on the output Pandas DataFrame 'df_by_day_norm'.
+
+        Parameters
+        ----------
+        df_by_day:
+            type: dataframe
+            These dataframe is output to by_day function.
+
+        win:
+            type: int
+            These dataframe is output to by_day function.
+            If True returns the DataFrame by group, default=True
+
+        Returns
+        -------
+        DataFrame
+        """
+        METHOD_NAME = "normalize_eng_by_day"
+        try:
+            groupby_date = (
+                df_by_day[["date", "engagement_rate_by_day"]]
+                .groupby(["date"])
+                .mean()
+                .reset_index()
+            )
+
+            groupby_date = groupby_date.rename(
+                columns={"engagement_rate_by_day": "engagement_rate_avg_by_day"}
+            )
+
+            groupby_date["windows_avrg"] = (
+                groupby_date["engagement_rate_avg_by_day"].rolling(win).mean()
+            )
+
+            df_by_day_norm = pd.merge(df_by_day, groupby_date, how="outer", on=["date"])
+
+            df_by_day_norm["engagement_norm"] = (
+                df_by_day_norm["engagement_rate_by_day"]
+                / df_by_day_norm["windows_avrg"]
+            )
+
+            df_by_day_norm = df_by_day_norm.iloc[
+                :,
+                ~df_by_day_norm.columns.isin(
+                    ["engagement_rate_avg_by_day", "windows_avrg"]
+                ),
+            ]
+
+            return df_by_day_norm
+        except Exception as e:
+            exception_type = sys.exc_info()[0]
+            print(ERR_SYS + str(exception_type))
+            print(e)
+            print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
+            return pd.DataFrame(
+                columns=[
+                    "_object_id",
+                    "_object_name",
+                    "group",
+                    "engagement_rate_by_accounts",
+                    "boundary",
+                    "rel_engagement_rate_by_accounts",
+                    "engagement_norm",
+                ],
+                dtype=object,
+            )
