@@ -14,7 +14,7 @@ class PolarityDistributionIG:
     This class computes the polarity of the texts.
     """
 
-    def __init__(self, df_comments, groups):
+    def __init__(self, df_comments, groups, r_group=False):
         """
         This method stores the input DataFrames and checks that they are not empty'.
 
@@ -28,12 +28,17 @@ class PolarityDistributionIG:
             type: dict
             Maps the groups (client, competition, archetype, trends) to the
             corresponding page ids for each group.
+        r_group:
+            type: bool
+            varibale that indicates if the class return the column group
+
         """
 
         METHOD_NAME = "__init__"
         df_comments_full = deepcopy(df_comments)
         self.df_comments_full = df_comments_full
         self.groups = groups
+        self.r_group = r_group
 
         try:
             if df_comments.empty:
@@ -81,6 +86,7 @@ class PolarityDistributionIG:
             ):
                 self.df_comments_full = Polarity().polarity(self.df_comments_full)
                 df_comments = self.df_comments_full
+                df_comments = df_comments.dropna(subset=["polarity"])
                 return df_comments
         except Exception as e:
             print(e)
@@ -142,11 +148,14 @@ class PolarityDistributionIG:
             if "post_owner_username" not in self.df_comments_full.keys():
                 self.df_comments_full["post_owner_username"] = "no name"
             self.df_comments_full["all"] = "all groups"
+            self.df_comments_full = self.df_comments_full.dropna(subset=["polarity"])
 
         try:
             if group_by == "post":
                 df_groupedpolarity = (
-                    self.df_comments_full.groupby("_post_id")["polarity"]
+                    self.df_comments_full.groupby(
+                        ["shortcode", "post_owner_id", "post_owner_username", "group"]
+                    )["polarity"]
                     .value_counts()
                     .unstack()
                     .fillna(0)
@@ -155,9 +164,15 @@ class PolarityDistributionIG:
                     orient="records"
                 )
                 df_groupedpolarity = df_groupedpolarity.reset_index().rename(
-                    columns={"_postr_id": "post_id"}
+                    columns={
+                        "shortcode": "post_id",
+                        "post_owner_id": "_object_id",
+                        "post_owner_username": "_object_name",
+                    }
                 )
-                return df_groupedpolarity.reset_index()[["post_id", "sentiment"]]
+                return df_groupedpolarity[
+                    ["_object_id", "_object_name", "post_id", "sentiment", "group"]
+                ]
             elif group_by == "account":
                 df_groupedpolarity = (
                     self.df_comments_full.groupby(
@@ -204,7 +219,13 @@ class PolarityDistributionIG:
             elif group_by == "time-account":
                 df_groupedpolarity = (
                     self.df_comments_full.groupby(
-                        ["_created_at", "_post_id", "_object_name"]
+                        [
+                            "created_at_utc",
+                            "post_owner_id",
+                            "post_owner_username",
+                            "shortcode",
+                            "group",
+                        ]
                     )["polarity"]
                     .value_counts()
                     .unstack()
@@ -214,11 +235,23 @@ class PolarityDistributionIG:
                     orient="records"
                 )
                 df_groupedpolarity = df_groupedpolarity.reset_index().rename(
-                    columns={"_created_at": "created_time", "_post_id": "_object_id"}
+                    columns={
+                        "created_at_utc": "created_time",
+                        "post_owner_id": "_object_id",
+                        "shortcode": "post_id",
+                        "post_owner_username": "_object_name",
+                    }
                 )
-                return df_groupedpolarity.reset_index()[
-                    ["created_time", "_object_id", "_object_name", "sentiment"]
+                columns = [
+                    "created_time",
+                    "_object_id",
+                    "_object_name",
+                    "sentiment",
+                    "post_id",
                 ]
+                if self.r_group == True:
+                    columns.append("group")
+                return df_groupedpolarity[columns].reset_index()
             else:
                 print(
                     f"Warning: {group_by} Invalid parameter value for parameter group_by, grouping by all"
